get method
Get a toast widget factory by id.
Returns the "success" factory with a debug warning if id is not found.
Prefer resolve for data-aware factory support.
Implementation
ToastStyleFactory? get(String id) {
return resolve(id, {});
}
Get a toast widget factory by id.
Returns the "success" factory with a debug warning if id is not found.
Prefer resolve for data-aware factory support.
ToastStyleFactory? get(String id) {
return resolve(id, {});
}