register method
Register a single toast style with the given id.
The factory is wrapped to ignore data (backward compatible).
Implementation
void register(String id, ToastStyleFactory factory) {
_styles[id] = (_) => factory;
}
Register a single toast style with the given id.
The factory is wrapped to ignore data (backward compatible).
void register(String id, ToastStyleFactory factory) {
_styles[id] = (_) => factory;
}