resolve method

ToastStyleFactory? resolve(
  1. String id,
  2. Map<String, dynamic> data
)

Resolve a toast style by id, passing data to data-aware factories. Returns the ToastStyleFactory ready to build the widget, or the "success" factory with a debug warning if id is not found.

Implementation

ToastStyleFactory? resolve(String id, Map<String, dynamic> data) {
  final dataFactory = _get(id);
  if (dataFactory == null) return null;
  return dataFactory(data);
}