TermLib class abstract

Implementers

Constructors

TermLib()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

disableRawMode() → void
dispose() → void
Releases any resources allocated by the terminal library.
enableRawMode() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setWindowHeight(int height) → int
setWindowWidth(int width) → int
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited