TermIOS class base

Inheritance
Implemented types
Available extensions

Constructors

TermIOS()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
c_cc ↔ Array<cc_t>
getter/setter pair
c_cflag ↔ int
getter/setter pair
c_iflag ↔ int
getter/setter pair
c_ispeed ↔ int
getter/setter pair
c_lflag ↔ int
getter/setter pair
c_oflag ↔ int
getter/setter pair
c_ospeed ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited