IEventBus class abstract

The event bus interface

Implementers

Constructors

IEventBus()

Properties

hashCode → int
The hash code for this object.
no setterinherited
history → List<EventBusHistoryEntry>
The history of events
no setter
inProgress$ → Stream<List<AppEvent>>
The list of events that are in progress
no setter
isBusy → bool
Whether the event bus is busy
no setter
isBusy$ → Stream<bool>
Whether the event bus is busy
no setter
last → AppEvent?
The last event
no setter
last$ → Stream<AppEvent?>
The last event
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearHistory() → void
Clear the history
complete(AppEvent event, {AppEvent? nextEvent}) → void
Complete a event
dispose() → void
Dispose the event bus
fire(AppEvent event) → void
Fire a event
isInProgress<T>() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on<T extends AppEvent>() → Stream<T>
Subscribe EventBus on a specific type of event, and register responder to it.
reset() → void
Reset the event bus
respond<T>(Responder<T> responder) → Subscription
Subscribe EventBus on a specific type of event, and register responder to it.
toString() → String
A string representation of this object.
inherited
watch(AppEvent event) → void
Fire a event and wait for it to be completed
whileInProgress<T extends AppEvent>() → Stream<bool>
Subscribe EventBus on a specific type of event, and register responder to it.

Operators

operator ==(Object other) → bool
The equality operator.
inherited