CurrencyMeta class

Currency meta data

Constructors

CurrencyMeta({required String symbol, required CurrencyInputFormatter formatter, String initialValue = ""})

Properties

formatter ↔ CurrencyInputFormatter
Currency formatter
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
initialValue ↔ String
Initial value
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
symbol ↔ String
Currency symbol
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited