dd method
dump the value to the console and exit the app. tag is optional.
On web the exit step is skipped (dart:io's exit() is unavailable).
Implementation
void dd({String? tag}) {
NyLogger.dd(this ?? "", tag);
}
dump the value to the console and exit the app. tag is optional.
On web the exit step is skipped (dart:io's exit() is unavailable).
void dd({String? tag}) {
NyLogger.dd(this ?? "", tag);
}