NyStatefulExt extension
Methods
-
faderBottom(
{double strength = 0.2, Color color = Colors.black}) → FadeOverlay -
Available on StatefulWidget, provided by the NyStatefulExt extension
Make gradient fader from the bottom of the widget.strengthranges from 0.0 (subtle) to 1.0 (strong). -
faderFrom(
{double strength = 0.2, Color color = Colors.black, AlignmentGeometry begin = Alignment.topCenter, AlignmentGeometry end = Alignment.bottomCenter}) → FadeOverlay -
Available on StatefulWidget, provided by the NyStatefulExt extension
Make gradient fader with custom alignment.strengthranges from 0.0 (subtle) to 1.0 (strong). -
faderLeft(
{double strength = 0.2, Color color = Colors.black}) → FadeOverlay -
Available on StatefulWidget, provided by the NyStatefulExt extension
Make gradient fader from the left of the widget.strengthranges from 0.0 (subtle) to 1.0 (strong). -
faderRight(
{double strength = 0.2, Color color = Colors.black}) → FadeOverlay -
Available on StatefulWidget, provided by the NyStatefulExt extension
Make gradient fader from the right of the widget.strengthranges from 0.0 (subtle) to 1.0 (strong). -
faderTop(
{double strength = 0.2, Color color = Colors.black}) → FadeOverlay -
Available on StatefulWidget, provided by the NyStatefulExt extension
Make gradient fader from the top of the widget.strengthranges from 0.0 (subtle) to 1.0 (strong). -
flexible(
{Key? key, int flex = 1, FlexFit fit = FlexFit.loose}) → Flexible -
Available on StatefulWidget, provided by the NyStatefulExt extension
Make a StatefulWidget Flexible. -
paddingOnly(
{double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Padding -
Available on StatefulWidget, provided by the NyStatefulExt extension
Add padding to the widget. -
paddingSymmetric(
{double horizontal = 0.0, double vertical = 0.0}) → Padding -
Available on StatefulWidget, provided by the NyStatefulExt extension
Add symmetric padding to the widget. -
visibleWhen(
bool condition) → Widget -
Available on StatefulWidget, provided by the NyStatefulExt extension
Make a widget visible when a condition is true.