NyEnvRegistry class

Registry for the user's generated Env class.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

isInitialized → bool
Checks if the env registry has been initialized.
no setter

Static Methods

containsKey(String key) → bool
Checks if an environment variable exists.
get(String key, {dynamic defaultValue}) → dynamic
Gets an environment variable by key.
register({required EnvGetter getter, EnvContainsKey? containsKey}) → void
Registers the env getter function.