clearTaskOnce static method

Future<void> clearTaskOnce(
  1. String name
)

Clear the executed state for a task scheduled with taskOnce. After calling this, the next taskOnce invocation with the same name will execute the callback again.

Implementation

static Future<void> clearTaskOnce(String name) async {
  await _secureStorage.delete(key: key("${name}_once"));
}