getKeyTaskOnce static method
Get the full storage key for a task that runs once. Use this with NyStorage.delete to reset the task.
Implementation
static String getKeyTaskOnce(String name) {
return key("${name}_once");
}
Get the full storage key for a task that runs once. Use this with NyStorage.delete to reset the task.
static String getKeyTaskOnce(String name) {
return key("${name}_once");
}