live/src/live_state_inspector library

Classes

LiveStateInspector
Describes the Nylo states on screen for metro live:run data.

Constants

nyLiveInspectItemLimit → const int
How many items of a collection field are encoded.

Properties

nyLiveInspectedState ↔ Object?
The state object metro live:run data last described.
getter/setter pair

Functions

nyLiveInspectJson(List<Object?> values) → String
Encodes the field values Metro read from nyLiveInspectedState.