addDisks method

void addDisks(
  1. Map<String, DiskConfig> disks, {
  2. String? defaultDisk,
})

Add disks for FileStorage and disk(), on top of the defaults (local, documents, cache, temp and assets); a disk with the same name as a default replaces it. defaultDisk names the disk used when none is given.

Implementation

void addDisks(Map<String, DiskConfig> disks, {String? defaultDisk}) {
  FileStorage.configure(disks: disks, defaultDisk: defaultDisk);
}