onDeepLink method

  1. @Deprecated('Use onIncomingLink((Uri uri) async => true) instead. ' 'The old form fires on every named route, not just deep links. ' 'Will be removed in 8.0.')
void onDeepLink(
  1. dynamic callback(
    1. String route,
    2. dynamic data
    )
)

Set the deep link action. e.g. nylo.onDeepLink((route, data) { print("Deep link route: $route"); print("Deep link data: $data"); });

Implementation

@Deprecated(
  'Use onIncomingLink((Uri uri) async => true) instead. '
  'The old form fires on every named route, not just deep links. '
  'Will be removed in 8.0.',
)
void onDeepLink(Function(String route, dynamic data) callback) {
  onDeepLinkAction = callback;
}