toJson method
Converts to a JSON-serializable map. Required by Flutter's NavigatorState which calls jsonEncode on route arguments during state restoration and post-navigation logging.
Implementation
Map<String, dynamic> toJson() => toMap();
Converts to a JSON-serializable map. Required by Flutter's NavigatorState which calls jsonEncode on route arguments during state restoration and post-navigation logging.
Map<String, dynamic> toJson() => toMap();