NyRouterOptions class

Options to configure a Nylo Router instance.

Constructors

NyRouterOptions({bool handleNameNotFoundUI = false, bool isLoggingEnabled = false, PageTransitionSettings pageTransitionSettings = const PageTransitionSettings.base(), GlobalKey<NavigatorState>? navigatorKey})
const

Properties

handleNameNotFoundUI → bool
final
hashCode → int
The hash code for this object.
no setterinherited
isLoggingEnabled → bool
Should display logs in console. Nylo Router prints some useful logs which can be helpful during development.
final
A navigator key lets NyRouter grab the NavigatorState from a MaterialApp or a CupertinoApp. All navigation operations (push, pop, etc) are carried out using this NavigatorState.
final
pageTransitionSettings → PageTransitionSettings
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited