NyRouterRoute class

The NyRouterRoute class is used to define a route in the Nylo Router.

Constructors

NyRouterRoute({required String name, required NyRouteView view, NyArgument? defaultArgs, NyQueryParameters? queryParameters, List<RouteGuard>? routeGuards, TransitionType? transitionType, PageTransitionType? pageTransitionType, PageTransitionSettings? pageTransitionSettings, dynamic initialRoute = false, dynamic unknownRoute = false, dynamic authPage = false})

Properties

builder ↔ NyRouterRouteBuilder
getter/setter pair
defaultArgs → NyArgument?
final
getTransitionType → TransitionType?
no setter
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
getter/setter pair
pageTransitionSettings ↔ PageTransitionSettings?
getter/setter pair
pageTransitionType ↔ PageTransitionType?
getter/setter pair
queryParameters → NyQueryParameters?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
view → NyRouteView
final

Methods

addPrefixToName(String prefix) → NyRouterRoute
Add a prefix to the route name.
addRouteGuard(RouteGuard guard) → NyRouterRoute
Add a route guard to the route.
addRouteGuards(List<RouteGuard> guards) → NyRouterRoute
Add route guards to the route
authenticatedRoute({bool when()?}) → NyRouterRoute
Set the authenticated route.
getAuthRoute() → bool
Get the auth route.
getInitialRoute() → bool
Get the initial route.
getPreviewRoute() → bool
Get the preview route flag.
getRouteGuards() → List<RouteGuard>
Get the route guards.
getUnknownRoute() → bool
Get the unknown route.
getWhen() → bool
Get the when function.
initialRoute({bool when()?}) → NyRouterRoute
Set the initial route.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
previewRoute() → NyRouterRoute
Set this route as a preview route. This will override any existing initialRoute and authenticatedRoute settings on all other routes, making this route the initial route. Useful for quickly previewing a specific route during development.
toString() → String
A string representation of this object.
inherited
transition(PageTransitionType transition) → NyRouterRoute
Add a transition to the route.
transitionSettings(PageTransitionSettings settings) → NyRouterRoute
Add a transition settings to the route.
transitionType(TransitionType transitionType) → NyRouterRoute
Add a transition type to the route.
unknownRoute() → NyRouterRoute
Set the unknown route.

Operators

operator ==(Object other) → bool
The equality operator.
inherited