RouteGuard class abstract

@deprecated Use NyRouteGuard instead. Legacy class interface for backward compatibility.

Implementers

Constructors

RouteGuard({PageRequest? pageRequest})

Properties

hashCode → int
The hash code for this object.
no setterinherited
pageRequest ↔ PageRequest?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRequest(PageRequest pageRequest) → Future<PageRequest?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited