RouteMatcher class

The RouteMatcher class is used to match the route with the registered routes.

Constructors

RouteMatcher(String path)

Properties

hashCode → int
The hash code for this object.
no setterinherited
path → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

findMatch(Map<String, NyRouterRoute> routeMappings) → RouteMatch?
Find matching route and extract parameters
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited