actingAsGuest static method

void actingAsGuest()

Set the test to run as an unauthenticated guest.

A semantic alias for logout that reads better in test setup.

Example:

NyTest.actingAsGuest();
expectGuest();

Implementation

static void actingAsGuest() {
  logout();
}