NyThemeStorage class

Storage service for theme persistence.

Uses FlutterSecureStorage for storing theme preferences. Includes migration logic from SharedPreferences (used by theme_provider).

Constructors

NyThemeStorage()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → Future<void>
Clear all theme storage data.
clearAll() → Future<void>
Clear all theme storage data including migration flag. Useful for testing and development.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readFollowSystem() → Future<bool?>
Read the follow system theme preference.
readPreferredDarkThemeId() → Future<String?>
Read the preferred dark theme ID.
readPreferredLightThemeId() → Future<String?>
Read the preferred light theme ID.
readThemeId() → Future<String?>
Read the saved theme ID.
resetMigration() → Future<void>
Delete migration flag (useful for testing).
saveFollowSystem(bool follow) → Future<void>
Save the follow system theme preference.
savePreferredDarkThemeId(String themeId) → Future<void>
Save the preferred dark theme ID.
savePreferredLightThemeId(String themeId) → Future<void>
Save the preferred light theme ID.
saveThemeId(String themeId) → Future<void>
Save the current theme ID.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited