CollectionViewStateActions class

State actions for CollectionView.

Example usage:

CollectionView.stateActions("my_list").reset();
CollectionView.stateActions("my_list").addItem(newItem);
CollectionView.stateActions("my_list").removeFromIndex(2);
Inheritance

Constructors

CollectionViewStateActions(String state)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String
getter/setter pairinherited

Methods

action(String action, {dynamic data}) → void
Call an action on a state. The action is a string that represents the action you want to perform on the state. The state is the state you want to perform the action on. The data is the data you want to pass to the action.
inherited
addItem(dynamic item) → void
Appends item to the end of the list.
insertItem(int index, dynamic item) → void
Inserts item at index in the list.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshData() → void
Re-fetches data from the data callback.
removeFromIndex(int index) → void
Removes the item at index from the list.
reset() → void
Resets the CollectionView, clearing data and re-fetching.
toString() String
A string representation of this object.
inherited
updateItemAtIndex(int index, dynamic item) → void
Replaces the item at index with item.

Operators

operator ==(Object other) bool
The equality operator.
inherited