FormStateActions class
The base class for form state actions This class is used to manage the state of the form fields
- Inheritance
-
- Object
- StateActions
- FormStateActions
- Implementers
Constructors
- FormStateActions(String state)
Properties
Methods
-
action(
String action, {dynamic data}) → void -
Call an action on a state.
The
actionis a string that represents the action you want to perform on the state. The state is the state you want to perform the action on. Thedatais the data you want to pass to the action.inherited -
clear(
) → void - Clear the field value
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setValue(
dynamic value) → void - Set the field value
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited