FormCheckboxStateActions class
Provides state management actions for NyFormCheckbox widgets.
This class extends FormStateActions to provide checkbox-specific state operations such as clearing the checkbox (unchecking it), setting values programmatically, or accessing the current checked state. Use NyFormCheckbox.stateActions to obtain an instance.
- Inheritance
-
- Object
- StateActions
- FormStateActions
- FormCheckboxStateActions
Constructors
- FormCheckboxStateActions(String state)
- Creates a FormCheckboxStateActions instance for the specified state.
Properties
Methods
-
action(
String action, {dynamic data}) → void -
Call an action on a state.
The
actionis a string that represents the action you want to perform on the state. The state is the state you want to perform the action on. Thedatais the data you want to pass to the action.inherited -
clear(
) → void -
Clear the field value
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setValue(
dynamic value) → void -
Set the field value
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited