FormPickerStateActions class
Provides state management actions for NyFormPicker widgets.
This class extends FormStateActions to provide picker-specific state operations such as clearing the selection, setting selected values, or triggering dropdown actions. Use NyFormPicker.stateActions to obtain an instance of this class.
- Inheritance
-
- Object
- StateActions
- FormStateActions
- FormPickerStateActions
Constructors
- FormPickerStateActions(String state)
- Creates a FormPickerStateActions instance for the specified state.
Properties
Methods
-
action(
String action, {dynamic data}) → void -
Call an action on a state.
The
actionis a string that represents the action you want to perform on the state. The state is the state you want to perform the action on. Thedatais the data you want to pass to the action.inherited -
clear(
) → void -
Clear the field value
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setOptions(
FormCollection options) → void - Set the options for the picker
-
setValue(
dynamic value) → void -
Set the field value
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited