FormRadioStateActions class

Provides state management actions for NyFormRadio widgets.

This class extends FormStateActions to provide radio button-specific state operations such as clearing the selection, setting the selected option, or accessing current values. Use NyFormRadio.stateActions to obtain an instance of this class.

Inheritance

Constructors

FormRadioStateActions(String state)
Creates a FormRadioStateActions instance for the specified state.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String
getter/setter pairinherited

Methods

action(String action, {dynamic data}) → void
Call an action on a state. The action is a string that represents the action you want to perform on the state. The state is the state you want to perform the action on. The data is the data you want to pass to the action.
inherited
clear() → void
Clear the field value
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setOptions(FormCollection options) → void
Set the options for the radio group
setValue(dynamic value) → void
Set the field value
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited