FormSliderStateActions class
Provides state management actions for NyFormSlider widgets.
This class extends FormStateActions to provide slider-specific state operations such as clearing the slider (resetting to minimum value), setting values programmatically, or accessing the current slider position. Use NyFormSlider.stateActions to obtain an instance.
- Inheritance
-
- Object
- StateActions
- FormStateActions
- FormSliderStateActions
Constructors
- FormSliderStateActions(String state)
- Creates a FormSliderStateActions instance for the specified state.
Properties
Methods
-
action(
String action, {dynamic data}) → void -
Call an action on a state.
The
actionis a string that represents the action you want to perform on the state. The state is the state you want to perform the action on. Thedatais the data you want to pass to the action.inherited -
clear(
) → void -
Clear the field value
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setValue(
dynamic value) → void -
Set the field value
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited