FormSwitchBoxStateActions class
Provides state management actions for NyFormSwitchBox widgets.
This class extends FormStateActions to provide switch-specific state operations such as clearing the switch (turning it off), setting values programmatically, or accessing the current on/off state. Use NyFormSwitchBox.stateActions to obtain an instance.
- Inheritance
-
- Object
- StateActions
- FormStateActions
- FormSwitchBoxStateActions
Constructors
- FormSwitchBoxStateActions(String state)
- Creates a FormSwitchBoxStateActions instance for the specified state.
Properties
Methods
-
action(
String action, {dynamic data}) → void -
Call an action on a state.
The
actionis a string that represents the action you want to perform on the state. The state is the state you want to perform the action on. Thedatais the data you want to pass to the action.inherited -
clear(
) → void -
Clear the field value
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setValue(
dynamic value) → void -
Set the field value
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited