TextFieldStateActions class

State actions for InputField.

Example usage:

InputField.stateActions("my_field").clear();
InputField.stateActions("my_field").setValue("Hello");
InputField.stateActions("my_field").focus();
InputField.stateActions("my_field").unfocus();
InputField.stateActions("my_field").toggleObscure();
Inheritance

Constructors

TextFieldStateActions(String state)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String
getter/setter pairinherited

Methods

action(String action, {dynamic data}) → void
Call an action on a state. The action is a string that represents the action you want to perform on the state. The state is the state you want to perform the action on. The data is the data you want to pass to the action.
inherited
clear() → void
Clear the field value
inherited
focus() → void
Request focus on the text field.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setValue(dynamic value) → void
Set the field value
inherited
toggleObscure() → void
Toggle password visibility.
toString() String
A string representation of this object.
inherited
unfocus() → void
Remove focus from the text field.

Operators

operator ==(Object other) bool
The equality operator.
inherited