widgets/src/language_switcher library
Classes
- LanguageSwitcher
- LanguageSwitcher is a widget that allows you to switch languages in your app. You can use it in the AppBar or as a bottom sheet modal using the showBottomModal method. Example:
- LanguageSwitcherAnimationStyle
- Configures animations for LanguageSwitcher inline popup trigger and bottom modal list items.