LanguageSwitcherStateActions class
State actions for LanguageSwitcher.
Example usage:
LanguageSwitcher.stateActions().refresh();
LanguageSwitcher.stateActions().setLanguage("es");
- Inheritance
-
- Object
- StateActions
- LanguageSwitcherStateActions
Constructors
Properties
Methods
-
action(
String action, {dynamic data}) → void -
Call an action on a state.
The
actionis a string that represents the action you want to perform on the state. The state is the state you want to perform the action on. Thedatais the data you want to pass to the action.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refresh(
) → void - Refresh the language switcher, re-fetching the language list.
-
setLanguage(
String localeCode) → void - Programmatically set the language by locale code.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited