NavigationHubStateActions class
Navigation hub state actions
- Inheritance
-
- Object
- StateActions
- NavigationHubStateActions
Constructors
Properties
Methods
-
action(
String action, {dynamic data}) → void -
Call an action on a state.
The
actionis a string that represents the action you want to perform on the state. The state is the state you want to perform the action on. Thedatais the data you want to pass to the action.inherited -
alertDisableTab(
{required int tab}) → void -
Disable the alert for the
tab -
alertEnableTab(
{required int tab}) → void -
Enable the alert for the
tab -
clearBadgeCount(
{required int tab}) → Future< void> - Clear the badge count E.g. MyNavigationHub.clearBadgeCount(tab: 0);
-
currentTabIndex(
int tabIndex) → void - Update the tab index
-
incrementBadgeCount(
{required int tab}) → Future< void> - Increment the badge count E.g. MyNavigationHub.incrementBadgeCount(tab: 0);
-
nextPage(
) → Future< bool> - Navigate to the next page in a journey layout Returns true if navigation was successful, false if already at last page
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
previousPage(
) → Future< bool> - Navigate to the previous page in a journey layout Returns true if navigation was successful, false if already at first page
-
refresh(
) → void - Refresh all tabs, forcing them to rebuild E.g. MyNavigationHub.refresh();
-
refreshTab(
int tabIndex) → void - Refresh a specific tab, forcing it to rebuild E.g. MyNavigationHub.refreshTab(0);
-
resetTabIndex(
int tabIndex) → void - Reset the tab
-
toString(
) → String -
A string representation of this object.
inherited
-
updateBadgeCount(
{required int tab, required int count}) → void - Update the badge count E.g. MyNavigationHub.updateBadgeCount(tab: 0, count: 2);
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited