refreshTab method
Refresh a specific tab, forcing it to rebuild E.g. MyNavigationHub.refreshTab(0);
Implementation
void refreshTab(int tabIndex) {
updateState(state, data: {"action": "refresh-tab", "tab-index": tabIndex});
}
Refresh a specific tab, forcing it to rebuild E.g. MyNavigationHub.refreshTab(0);
void refreshTab(int tabIndex) {
updateState(state, data: {"action": "refresh-tab", "tab-index": tabIndex});
}