SeedRun class
What happened when a seeder ran up or down.
Constructors
Properties
- direction → String
-
upordown.final - error ↔ String?
-
Why the run failed, or null when it succeeded.
getter/setter pair
- failed → bool
-
Whether the run failed.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
log
→ List<
Map< String, String> > -
The changes (entries with
level: change) and messages, in the order they happened.no setter - ms → int
-
How long the run took, in milliseconds.
no setter
- name → String
-
The seeder's name, e.g.
demo_user.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add(
Map< String, String> entry) → void - Adds a change or message to the run.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - The JSON sent to Metro.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited