SeedRun constructor
Creates a run of the seeder name in direction (up or down).
Everything added to the run is also added to parent, so a seeder that
runs other seeders shows their changes too.
Implementation
SeedRun(this.name, this.direction, {SeedRun? parent}) : _parent = parent;