onDeepLink method
- @Deprecated('Use onIncomingLink((Uri uri) async => true) instead. ' 'The old form fires on every named route, not just deep links. ' 'Will be removed in 8.0.')
- dynamic callback(
- String route,
- dynamic data
Set the deep link action. e.g. nylo.onDeepLink((route, data) { print("Deep link route: $route"); print("Deep link data: $data"); });
Implementation
@Deprecated(
'Use onIncomingLink((Uri uri) async => true) instead. '
'The old form fires on every named route, not just deep links. '
'Will be removed in 8.0.',
)
void onDeepLink(Function(String route, dynamic data) callback) {
onDeepLinkAction = callback;
}