CollectionViewStateActions class
State actions for CollectionView.
Example usage:
CollectionView.stateActions("my_list").reset();
CollectionView.stateActions("my_list").addItem(newItem);
CollectionView.stateActions("my_list").removeFromIndex(2);
- Inheritance
-
- Object
- StateActions
- CollectionViewStateActions
Constructors
- CollectionViewStateActions(String state)
Properties
Methods
-
action(
String action, {dynamic data}) → void -
Call an action on a state.
The
actionis a string that represents the action you want to perform on the state. The state is the state you want to perform the action on. Thedatais the data you want to pass to the action.inherited -
addItem(
dynamic item) → void -
Appends
itemto the end of the list. -
insertItem(
int index, dynamic item) → void -
Inserts
itematindexin the list. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refreshData(
) → void - Re-fetches data from the data callback.
-
removeFromIndex(
int index) → void -
Removes the item at
indexfrom the list. -
reset(
) → void - Resets the CollectionView, clearing data and re-fetching.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateItemAtIndex(
int index, dynamic item) → void -
Replaces the item at
indexwithitem.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited